### array class

sub new {
    my $class = shift;

    my $self = { base => () };

    bless $self, $class;

}

### toolsarray to vector class
sub arrayToVector {
    my ($self, $array) = @_;

    my $v = vector->new;
    
    for (my $i = 0; $i < $array->{length}; $i++) {
	push($v->{base}, $array->{base}[$i]);
    }

    return $v;
}

sub add {
    my ($self, $value) = @_;

    push($self->{base}, $value);
}

1;
